==> mastapy-13.0.4b1.tar.gz: mastapy-13.0.4b1/mastapy/system_model/drawing/_2273.py <==
"""PartAnalysisCaseWithContourViewable"""

from __future__ import annotations

from typing import TYPE_CHECKING, TypeVar, List

from mastapy._internal.type_enforcement import enforce_parameter_types
from mastapy._internal.implicit import enum_with_selected_value
from mastapy.utility.enums import _1840, _1841
from mastapy._internal import enum_with_selected_value_runtime, conversion, constructor
from mastapy import _0
from mastapy._internal.cast_exception import CastException
from mastapy._internal.python_net import python_net_import

_PART_ANALYSIS_CASE_WITH_CONTOUR_VIEWABLE = python_net_import(
    "SMT.MastaAPI.SystemModel.Drawing", "PartAnalysisCaseWithContourViewable"
)

if TYPE_CHECKING:
    from mastapy.system_model.drawing import (
        _2266,
        _2263,
        _2264,
        _2268,
        _2269,
        _2271,
        _2280,
    )


__docformat__ = "restructuredtext en"
__all__ = ("PartAnalysisCaseWithContourViewable",)


Self = TypeVar("Self", bound="PartAnalysisCaseWithContourViewable")


class PartAnalysisCaseWithContourViewable(_0.APIBase):
    """PartAnalysisCaseWithContourViewable

    This is a mastapy class.
    """

    TYPE = _PART_ANALYSIS_CASE_WITH_CONTOUR_VIEWABLE
    _CastSelf = TypeVar("_CastSelf", bound="_Cast_PartAnalysisCaseWithContourViewable")

    class _Cast_PartAnalysisCaseWithContourViewable:
        """Special nested class for casting PartAnalysisCaseWithContourViewable to subclasses."""

        def __init__(
            self: "PartAnalysisCaseWithContourViewable._Cast_PartAnalysisCaseWithContourViewable",
            parent: "PartAnalysisCaseWithContourViewable",
        ):
            self._parent = parent

        @property
        def abstract_system_deflection_viewable(
            self: "PartAnalysisCaseWithContourViewable._Cast_PartAnalysisCaseWithContourViewable",
        ) -> "_2263.AbstractSystemDeflectionViewable":
            from mastapy.system_model.drawing import _2263

            return self._parent._cast(_2263.AbstractSystemDeflectionViewable)

        @property
        def advanced_system_deflection_viewable(
            self: "PartAnalysisCaseWithContourViewable._Cast_PartAnalysisCaseWithContourViewable",
        ) -> "_2264.AdvancedSystemDeflectionViewable":
            from mastapy.system_model.drawing import _2264

            return self._parent._cast(_2264.AdvancedSystemDeflectionViewable)

        @property
        def dynamic_analysis_viewable(
            self: "PartAnalysisCaseWithContourViewable._Cast_PartAnalysisCaseWithContourViewable",
        ) -> "_2268.DynamicAnalysisViewable":
            from mastapy.system_model.drawing import _2268

            return self._parent._cast(_2268.DynamicAnalysisViewable)

        @property
        def harmonic_analysis_viewable(
            self: "PartAnalysisCaseWithContourViewable._Cast_PartAnalysisCaseWithContourViewable",
        ) -> "_2269.HarmonicAnalysisViewable":
            from mastapy.system_model.drawing import _2269

            return self._parent._cast(_2269.HarmonicAnalysisViewable)

        @property
        def modal_analysis_viewable(
            self: "PartAnalysisCaseWithContourViewable._Cast_PartAnalysisCaseWithContourViewable",
        ) -> "_2271.ModalAnalysisViewable":
            from mastapy.system_model.drawing import _2271

            return self._parent._cast(_2271.ModalAnalysisViewable)

        @property
        def system_deflection_viewable(
            self: "PartAnalysisCaseWithContourViewable._Cast_PartAnalysisCaseWithContourViewable",
        ) -> "_2280.SystemDeflectionViewable":
            from mastapy.system_model.drawing import _2280

            return self._parent._cast(_2280.SystemDeflectionViewable)

        @property
        def part_analysis_case_with_contour_viewable(
            self: "PartAnalysisCaseWithContourViewable._Cast_PartAnalysisCaseWithContourViewable",
        ) -> "PartAnalysisCaseWithContourViewable":
            return self._parent

        def __getattr__(
            self: "PartAnalysisCaseWithContourViewable._Cast_PartAnalysisCaseWithContourViewable",
            name: str,
        ):
            try:
                return self.__dict__[name]
            except KeyError:
                class_name = "".join(n.capitalize() for n in name.split("_"))
                raise CastException(
                    f'Detected an invalid cast. Cannot cast to type "{class_name}"'
                ) from None

    def __init__(
        self: Self, instance_to_wrap: "PartAnalysisCaseWithContourViewable.TYPE"
    ):
        super().__init__(instance_to_wrap)
        self._freeze()

    @property
    def contour(
        self: Self,
    ) -> "enum_with_selected_value.EnumWithSelectedValue_ThreeDViewContourOptionFirstSelection":
        """EnumWithSelectedValue[mastapy.utility.enums.ThreeDViewContourOptionFirstSelection]"""
        temp = self.wrapped.Contour

        if temp is None:
            return None

        value = (
            enum_with_selected_value.EnumWithSelectedValue_ThreeDViewContourOptionFirstSelection.wrapped_type()
        )
        return enum_with_selected_value_runtime.create(temp, value)

    @contour.setter
    @enforce_parameter_types
    def contour(self: Self, value: "_1840.ThreeDViewContourOptionFirstSelection"):
        wrapper_type = enum_with_selected_value_runtime.ENUM_WITH_SELECTED_VALUE
        enclosed_type = (
            enum_with_selected_value.EnumWithSelectedValue_ThreeDViewContourOptionFirstSelection.implicit_type()
        )
        value = conversion.mp_to_pn_enum(value, enclosed_type)
        value = wrapper_type[enclosed_type](value)
        self.wrapped.Contour = value

    @property
    def contour_secondary(
        self: Self,
    ) -> "enum_with_selected_value.EnumWithSelectedValue_ThreeDViewContourOptionSecondSelection":
        """EnumWithSelectedValue[mastapy.utility.enums.ThreeDViewContourOptionSecondSelection]"""
        temp = self.wrapped.ContourSecondary

        if temp is None:
            return None

        value = (
            enum_with_selected_value.EnumWithSelectedValue_ThreeDViewContourOptionSecondSelection.wrapped_type()
        )
        return enum_with_selected_value_runtime.create(temp, value)

    @contour_secondary.setter
    @enforce_parameter_types
    def contour_secondary(
        self: Self, value: "_1841.ThreeDViewContourOptionSecondSelection"
    ):
        wrapper_type = enum_with_selected_value_runtime.ENUM_WITH_SELECTED_VALUE
        enclosed_type = (
            enum_with_selected_value.EnumWithSelectedValue_ThreeDViewContourOptionSecondSelection.implicit_type()
        )
        value = conversion.mp_to_pn_enum(value, enclosed_type)
        value = wrapper_type[enclosed_type](value)
        self.wrapped.ContourSecondary = value

    @property
    def contour_draw_style(self: Self) -> "_2266.ContourDrawStyle":
        """mastapy.system_model.drawing.ContourDrawStyle

        Note:
            This property is readonly.
        """
        temp = self.wrapped.ContourDrawStyle

        if temp is None:
            return None

        type_ = temp.GetType()
        return constructor.new(type_.Namespace, type_.Name)(temp)

    @property
    def report_names(self: Self) -> "List[str]":
        """List[str]

        Note:
            This property is readonly.
        """
        temp = self.wrapped.ReportNames

        if temp is None:
            return None

        value = conversion.pn_to_mp_objects_in_list(temp, str)

        if value is None:
            return None

        return value

    @enforce_parameter_types
    def output_default_report_to(self: Self, file_path: "str"):
        """Method does not return.

        Args:
            file_path (str)
        """
        file_path = str(file_path)
        self.wrapped.OutputDefaultReportTo(file_path if file_path else "")

    def get_default_report_with_encoded_images(self: Self) -> "str":
        """str"""
        method_result = self.wrapped.GetDefaultReportWithEncodedImages()
        return method_result

    @enforce_parameter_types
    def output_active_report_to(self: Self, file_path: "str"):
        """Method does not return.

        Args:
            file_path (str)
        """
        file_path = str(file_path)
        self.wrapped.OutputActiveReportTo(file_path if file_path else "")

    @enforce_parameter_types
    def output_active_report_as_text_to(self: Self, file_path: "str"):
        """Method does not return.

        Args:
            file_path (str)
        """
        file_path = str(file_path)
        self.wrapped.OutputActiveReportAsTextTo(file_path if file_path else "")

    def get_active_report_with_encoded_images(self: Self) -> "str":
        """str"""
        method_result = self.wrapped.GetActiveReportWithEncodedImages()
        return method_result

    @enforce_parameter_types
    def output_named_report_to(self: Self, report_name: "str", file_path: "str"):
        """Method does not return.

        Args:
            report_name (str)
            file_path (str)
        """
        report_name = str(report_name)
        file_path = str(file_path)
        self.wrapped.OutputNamedReportTo(
            report_name if report_name else "", file_path if file_path else ""
        )

    @enforce_parameter_types
    def output_named_report_as_masta_report(
        self: Self, report_name: "str", file_path: "str"
    ):
        """Method does not return.

        Args:
            report_name (str)
            file_path (str)
        """
        report_name = str(report_name)
        file_path = str(file_path)
        self.wrapped.OutputNamedReportAsMastaReport(
            report_name if report_name else "", file_path if file_path else ""
        )

    @enforce_parameter_types
    def output_named_report_as_text_to(
        self: Self, report_name: "str", file_path: "str"
    ):
        """Method does not return.

        Args:
            report_name (str)
            file_path (str)
        """
        report_name = str(report_name)
        file_path = str(file_path)
        self.wrapped.OutputNamedReportAsTextTo(
            report_name if report_name else "", file_path if file_path else ""
        )

    @enforce_parameter_types
    def get_named_report_with_encoded_images(self: Self, report_name: "str") -> "str":
        """str

        Args:
            report_name (str)
        """
        report_name = str(report_name)
        method_result = self.wrapped.GetNamedReportWithEncodedImages(
            report_name if report_name else ""
        )
        return method_result

    @property
    def cast_to(
        self: Self,
    ) -> (
        "PartAnalysisCaseWithContourViewable._Cast_PartAnalysisCaseWithContourViewable"
    ):
        return self._Cast_PartAnalysisCaseWithContourViewable(self)

==> mastapy-13.1.0a4.tar.gz: mastapy-13.1.0a4/mastapy/system_model/drawing/_2273.py <==
"""RotorDynamicsViewable"""

from __future__ import annotations

from typing import TYPE_CHECKING, TypeVar, List

from mastapy._internal.type_enforcement import enforce_parameter_types
from mastapy._internal import constructor, conversion
from mastapy import _0
from mastapy._internal.cast_exception import CastException
from mastapy._internal.python_net import python_net_import

_ROTOR_DYNAMICS_VIEWABLE = python_net_import(
    "SMT.MastaAPI.SystemModel.Drawing", "RotorDynamicsViewable"
)

if TYPE_CHECKING:
    from mastapy.system_model.analyses_and_results.rotor_dynamics import _4049
    from mastapy.system_model.drawing import _2265, _2275, _2276


__docformat__ = "restructuredtext en"
__all__ = ("RotorDynamicsViewable",)


Self = TypeVar("Self", bound="RotorDynamicsViewable")


class RotorDynamicsViewable(_0.APIBase):
    """RotorDynamicsViewable

    This is a mastapy class.
    """

    TYPE = _ROTOR_DYNAMICS_VIEWABLE
    _CastSelf = TypeVar("_CastSelf", bound="_Cast_RotorDynamicsViewable")

    class _Cast_RotorDynamicsViewable:
        """Special nested class for casting RotorDynamicsViewable to subclasses."""

        def __init__(
            self: "RotorDynamicsViewable._Cast_RotorDynamicsViewable",
            parent: "RotorDynamicsViewable",
        ):
            self._parent = parent

        @property
        def critical_speed_analysis_viewable(
            self: "RotorDynamicsViewable._Cast_RotorDynamicsViewable",
        ) -> "_2265.CriticalSpeedAnalysisViewable":
            from mastapy.system_model.drawing import _2265

            return self._parent._cast(_2265.CriticalSpeedAnalysisViewable)

        @property
        def stability_analysis_viewable(
            self: "RotorDynamicsViewable._Cast_RotorDynamicsViewable",
        ) -> "_2275.StabilityAnalysisViewable":
            from mastapy.system_model.drawing import _2275

            return self._parent._cast(_2275.StabilityAnalysisViewable)

        @property
        def steady_state_synchronous_response_viewable(
            self: "RotorDynamicsViewable._Cast_RotorDynamicsViewable",
        ) -> "_2276.SteadyStateSynchronousResponseViewable":
            from mastapy.system_model.drawing import _2276

            return self._parent._cast(_2276.SteadyStateSynchronousResponseViewable)

        @property
        def rotor_dynamics_viewable(
            self: "RotorDynamicsViewable._Cast_RotorDynamicsViewable",
        ) -> "RotorDynamicsViewable":
            return self._parent

        def __getattr__(
            self: "RotorDynamicsViewable._Cast_RotorDynamicsViewable", name: str
        ):
            try:
                return self.__dict__[name]
            except KeyError:
                class_name = "".join(n.capitalize() for n in name.split("_"))
                raise CastException(
                    f'Detected an invalid cast. Cannot cast to type "{class_name}"'
                ) from None

    def __init__(self: Self, instance_to_wrap: "RotorDynamicsViewable.TYPE"):
        super().__init__(instance_to_wrap)
        self._freeze()

    @property
    def rotor_dynamics(self: Self) -> "_4049.RotorDynamicsDrawStyle":
        """mastapy.system_model.analyses_and_results.rotor_dynamics.RotorDynamicsDrawStyle

        Note:
            This property is readonly.
        """
        temp = self.wrapped.RotorDynamics

        if temp is None:
            return None

        type_ = temp.GetType()
        return constructor.new(type_.Namespace, type_.Name)(temp)

    @property
    def report_names(self: Self) -> "List[str]":
        """List[str]

        Note:
            This property is readonly.
        """
        temp = self.wrapped.ReportNames

        if temp is None:
            return None

        value = conversion.pn_to_mp_objects_in_list(temp, str)

        if value is None:
            return None

        return value

    @enforce_parameter_types
    def output_default_report_to(self: Self, file_path: "str"):
        """Method does not return.

        Args:
            file_path (str)
        """
        file_path = str(file_path)
        self.wrapped.OutputDefaultReportTo(file_path if file_path else "")

    def get_default_report_with_encoded_images(self: Self) -> "str":
        """str"""
        method_result = self.wrapped.GetDefaultReportWithEncodedImages()
        return method_result

    @enforce_parameter_types
    def output_active_report_to(self: Self, file_path: "str"):
        """Method does not return.

        Args:
            file_path (str)
        """
        file_path = str(file_path)
        self.wrapped.OutputActiveReportTo(file_path if file_path else "")

    @enforce_parameter_types
    def output_active_report_as_text_to(self: Self, file_path: "str"):
        """Method does not return.

        Args:
            file_path (str)
        """
        file_path = str(file_path)
        self.wrapped.OutputActiveReportAsTextTo(file_path if file_path else "")

    def get_active_report_with_encoded_images(self: Self) -> "str":
        """str"""
        method_result = self.wrapped.GetActiveReportWithEncodedImages()
        return method_result

    @enforce_parameter_types
    def output_named_report_to(self: Self, report_name: "str", file_path: "str"):
        """Method does not return.

        Args:
            report_name (str)
            file_path (str)
        """
        report_name = str(report_name)
        file_path = str(file_path)
        self.wrapped.OutputNamedReportTo(
            report_name if report_name else "", file_path if file_path else ""
        )

    @enforce_parameter_types
    def output_named_report_as_masta_report(
        self: Self, report_name: "str", file_path: "str"
    ):
        """Method does not return.

        Args:
            report_name (str)
            file_path (str)
        """
        report_name = str(report_name)
        file_path = str(file_path)
        self.wrapped.OutputNamedReportAsMastaReport(
            report_name if report_name else "", file_path if file_path else ""
        )

    @enforce_parameter_types
    def output_named_report_as_text_to(
        self: Self, report_name: "str", file_path: "str"
    ):
        """Method does not return.

        Args:
            report_name (str)
            file_path (str)
        """
        report_name = str(report_name)
        file_path = str(file_path)
        self.wrapped.OutputNamedReportAsTextTo(
            report_name if report_name else "", file_path if file_path else ""
        )

    @enforce_parameter_types
    def get_named_report_with_encoded_images(self: Self, report_name: "str") -> "str":
        """str

        Args:
            report_name (str)
        """
        report_name = str(report_name)
        method_result = self.wrapped.GetNamedReportWithEncodedImages(
            report_name if report_name else ""
        )
        return method_result

    @property
    def cast_to(self: Self) -> "RotorDynamicsViewable._Cast_RotorDynamicsViewable":
        return self._Cast_RotorDynamicsViewable(self)
